@@ -1,22 +1,31 @@
 from scipy.constants import nano, milli
-from to_precision import auto_notation
+from sigfig import round
 from glob import glob
 import rosspy
 import pandas
-import os
-import re
+import os, re
 
 def isnumber(obj):
+    
     if type(obj) is float or type(obj) is int:
         return True
     
 def test_init():
     ross = rosspy.ROSSPkg(verbose = False)
 
-    assert type(ross.parameters) is dict
-    assert type(ross.variables) is dict
-    assert type(ross.results) is dict
-    assert type(ross.verbose) is bool
+    # ensure that the dictionaries are created
+    for dic in [ross.parameters, ross.variables, ross.results]:
+        assert type(dic) is dict
+    
+    # ensure that the booleans are created
+    for boo in [ross.verbose, ross.jupyter,]:
+        assert type(boo) is bool
+        
+    # ensure that the booleans are created
+    for lis in [ross.databases, ross.feed_sources,]:
+        assert type(list) is list
+        
+    assert os.path.exists(ross.parameters['root_path'])
 
 def test_define_general():
     ross = rosspy.ROSSPkg(verbose = False)
@@ -26,18 +35,18 @@ def test_define_general():
     ross.define_general(database_selection)
 
     # affirm qualities of the simulation
-    assert int(auto_notation(ross.parameters['water_mw'], 2)) == 18
-    assert int(auto_notation(ross.parameters['water_grams_per_liter'], 2)) == 1.0e3
+    assert int(round(ross.parameters['water_mw'], 2)) == 18
+    assert int(round(ross.parameters['water_grams_per_liter'], 2)) == 1.0e3
     for param in ['os', 'simulation_type', 'simulation', 'domain', 'root_path', 'database_selection']:
         assert type(ross.parameters[param]) is str
         
     assert type(ross.parameters['quantity_of_modules']) is int
 
-    for path in ['root_path']:
+    for path in ['database_path']:
         assert os.path.exists(ross.parameters[path])
 
-    assert type(ross.elements) is dict
-    assert type(ross.minerals) is dict
+    for dic in [ross.elements, ross.minerals,]:
+        assert type(dic) is dict
 
 def test_transport():
     ross = rosspy.ROSSPkg(verbose = False)
@@ -48,7 +57,7 @@ def test_transport():
         'module_diameter_mm':160,
         'permeate_tube_diameter_mm':9,  
         'module_length_m':1,  
-        'permeate_flow_m3_per_day':45,   
+        'permeate_flow_m3_per_hour':45,   
         'max_feed_flow_m3_per_hour':10,
         'membrane_thickness_mm':300 * (nano / milli),  
         'feed_thickness_mm':0.98,
@@ -62,7 +71,7 @@ def test_transport():
     ross.transport(simulation_time, module_characteristics = module_characteristics)
 
     # affirm qualities of the simulation
-    for param in ['module_diameter_mm', 'permeate_tube_diameter_mm', 'module_length_m', 'permeate_flow_m3_per_day', 'max_feed_flow_m3_per_hour', 'membrane_thickness_mm', 'feed_thickness_mm', 'active_m2', 'permeate_thickness_mm', 'polysulfonic_layer_thickness_mm', 'support_layer_thickness_mm']:
+    for param in ['module_diameter_mm', 'permeate_tube_diameter_mm', 'module_length_m', 'permeate_flow_m3_per_hour', 'max_feed_flow_m3_per_hour', 'membrane_thickness_mm', 'feed_thickness_mm', 'active_m2', 'permeate_thickness_mm', 'polysulfonic_layer_thickness_mm', 'support_layer_thickness_mm']:
         assert ross.parameters[param] == module_characteristics[param]   
 
     for param in ['simulation_time', 'exchange_factor', 'module_diameter_mm', 'permeate_tube_diameter_mm', 'module_length_m', 'permeate_flow_m3_per_day', 'max_feed_flow_m3_per_hour', 'membrane_thickness_mm', 'feed_thickness_mm', 'active_m2', 'permeate_thickness_mm', 'polysulfonic_layer_thickness_mm', 'support_layer_thickness_mm', 'repeated_membrane_winding_mm', 'cells_per_module', 'active_m2_cell', 'timestep', 'permeate_moles_per_cell']:
@@ -73,6 +82,9 @@ def test_transport():
 
     for param in ['domain', 'simulation_perspective']:
         assert type(ross.parameters[param]) is str
+        
+    for lis in ['transport_block']:
+        assert type(ross.results[list]) is list
 
 def test_reaction():
     ross = rosspy.ROSSPkg(verbose = False)
@@ -86,9 +98,8 @@ def test_reaction():
     # affirm qualities of the simulation
     for line in ross.results['reaction_block']:
         assert type(line) is str   
-        if line not in ['', '\n', None, ' ']:
-            print(line)
-            assert re.search('REACTION|\#',line) 
+        if line not in ['', '\n', None, ' ', '\n\tH2O -1; \d+', '#[A-Za-z\s]+']:
+            assert re.search('REACTION|\#',line)
 
 def test_solutions():
     database_selection = 'pitzer'
@@ -125,6 +136,8 @@ def test_equilibrium_phases():
     # affirm qualities of the simulation
     for var in ['cell_meters', 'feed_cubic_meters', 'feed_kg', 'feed_moles', 'Reynold\'s number', 'feed_kg_cell', 'feed_moles_cell']:
         assert isnumber(ross.variables[var])
+        
+    assert type(ross.variables['described_minerals']) is dict
 
     for line in ross.results['equilibrium_phases_block']:
         assert type(line) is str   
@@ -169,7 +182,7 @@ def test_export():
     for line in ross.results['complete_lines']:
         assert type(line) is str
         
-    for file in ['parameters.csv', 'variables.csv']:
+    for file in ['parameters.csv', 'variables.csv', 'effluent_predictions.csv']:
         assert os.path.exists(os.path.join(ross.simulation_path, file))
     
 def test_parse_input():
@@ -202,9 +215,8 @@ def test_execute():
     ross.execute()
 
     # affirm qualities of the simulation
-    assert os.path.exists(ross.parameters['output_path'])
-    assert os.path.exists(os.path.join(ross.simulation_path, 'parameters.csv'))
-    assert os.path.exists(os.path.join(ross.simulation_path, 'variables.csv'))
+    for path in [ross.parameters['output_path'], os.path.join(ross.simulation_path, 'parameters.csv'), os.path.join(ross.simulation_path, 'variables.csv'), os.path.join(ross.simulation_path, 'effluent_predictions.csv')]:
+        assert os.path.exists(path)
     assert type(ross.results['csv_data']) is pandas.core.frame.DataFrame
     assert type(ross.variables['run_time (s)']) is float
 
@@ -230,7 +242,7 @@ def test_process_selected_output_all_distance_brine():
     for var in ['initial_solution_mass', 'final_solution_mass','simulation_cf','final_time']:
         ross.variables[var]
 
-    for file in ['brine.svg', 'input.pqi', 'parameters.csv', 'brine_concentrations.csv', 'selected_output.pqo', 'variables.csv']:
+    for file in ['brine.svg', 'input.pqi', 'parameters.csv', 'brine_concentrations.csv', 'selected_output.csv', 'variables.csv', 'effluent_predictions.csv']:
         assert os.path.exists(os.path.join(ross.simulation_path, file))
 
 def test_process_selected_output_all_time_brine():
@@ -255,7 +267,7 @@ def test_process_selected_output_all_time_brine():
     for var in ['initial_solution_mass', 'final_solution_mass','simulation_cf','final_time']:
         ross.variables[var]
         
-    for file in ['brine.svg', 'input.pqi', 'parameters.csv', 'brine_concentrations.csv', 'selected_output.pqo', 'variables.csv']:
+    for file in ['brine.svg', 'input.pqi', 'parameters.csv', 'brine_concentrations.csv', 'selected_output.csv', 'variables.csv', 'effluent_predictions.csv']:
         assert os.path.exists(os.path.join(ross.simulation_path, file))
 
 def test_process_selected_output_all_distance_scaling():
@@ -278,7 +290,7 @@ def test_process_selected_output_all_distance_scaling():
     for var in ['precipitated_minerals']:
         ross.variables[var]
 
-    for file in ['all_minerals.svg', 'input.pqi', 'parameters.csv', 'scaling_data.csv', 'selected_output.pqo', 'variables.csv']:
+    for file in ['all_minerals.svg', 'input.pqi', 'parameters.csv', 'scaling_data.csv', 'selected_output.csv', 'variables.csv', 'effluent_predictions.csv', 'scale_ions.json']:
         assert os.path.exists(os.path.join(ross.simulation_path, file))
 
 def test_process_selected_output_all_time_scaling():
@@ -302,7 +314,7 @@ def test_process_selected_output_all_time_scaling():
     for var in ['initial_solution_mass', 'final_solution_mass', 'simulation_cf', 'final_time']:
         ross.variables[var]
 
-    for file in ['Barite.svg', 'Halite.svg', 'input.pqi', 'parameters.csv', 'scaling_data.csv', 'selected_output.pqo', 'variables.csv']:
+    for file in ['Barite.svg', 'Halite.svg', 'input.pqi', 'parameters.csv', 'scaling_data.csv', 'selected_output.csv', 'variables.csv', 'effluent_predictions.csv', 'scale_ions.json']:
         assert os.path.exists(os.path.join(ross.simulation_path, file))
     
 def test_test():    
@@ -310,5 +322,5 @@ def test_test():
     ross.test()
     
     # affirm the execution of the simulation
-    for file in ['all_minerals.svg', 'input.pqi', 'parameters.csv', 'scaling_data.csv', 'selected_output.pqo', 'variables.csv']:
+    for file in ['all_minerals.svg', 'input.pqi', 'parameters.csv', 'scaling_data.csv', 'selected_output.csv', 'variables.csv', 'effluent_predictions.csv', 'scale_ions.json']:
         assert os.path.exists(os.path.join(ross.simulation_path, file))
\ No newline at end of file
